@@ -1,18 +1,20 @@
 #!/usr/bin/env bash
-# vim:ts=4:sw=4:noet
+# vim: ts=4 sw=4 noet
 #
 # Creates a Python 3 virtual environment. The target directory can be passed
 # as a parameter. The default path is '.venv' in the current directory.
 
-dir="${1:-.venv}"
+venv="${1:-.venv}"
 
 set -e
-if [ -d "${dir}" ]; then
-	echo >&2 "Directory '${dir}' already exists, exiting."
+if [ -r "${venv}" ]; then
+	echo >&2 "${venv} already exists, exiting."
 	exit 1
 fi
-python3 -m venv "${dir}"
-source "${dir}/bin/activate"
+python3 -m venv "${venv}"
+# shellcheck disable=SC1091
+. "${venv}/bin/activate"
 
 set +e
 pip install -U pip setuptools wheel || true
+unset venv
